@@ -89,7 +89,8 @@ def shape(a, dim: Int):
 
 
 @dispatch
-def shape(a, *dims: Int):
+def shape(a, dim: Int, *dims: Int):
+    dims = (dim,) + dims
     a_shape = B.shape(a)
     subshape = tuple(a_shape[i] for i in dims)
     if LazyShapes.enabled:
